@@ -29,6 +29,7 @@ custom_error! {pub ProgramError
     ZeroLenFile = "File seems empty",
     UnmappableFile = "File can't be mapped",
     UnprintableFile = "File can't be printed", // has characters that can't be printed without escaping
+    SyntectCrashed { details: String } = "Syntect crashed on {details:?}",
 }
 
 custom_error! {pub TreeBuildError
@@ -48,6 +49,7 @@ custom_error! {pub ConfError
     UnknownInternal {verb: String}                  = "not a known internal: {}",
     InvalidSearchMode {details: String}             = "invalid search mode: {}",
     InvalidKey {raw: String}                        = "not a valid key: {}",
+    ParseKey {source: crokey::ParseKeyError}        = "{}",
     ReservedKey {key: String}                       = "reserved key: {}",
     UnexpectedInternalArg {invocation: String}      = "unexpected argument for internal: {}",
     InvalidCols {details: String}                   = "invalid cols definition: {}",
